Package: syntenet
Title: Inference And Analysis Of Synteny Networks
Version: 1.15.0
Date: 2022-03-28
Authors@R: 
    c(
    person(given = "Fabrício",
           family = "Almeida-Silva",
           role = c("aut", "cre"),
           email = "fabricio_almeidasilva@hotmail.com",
           comment = c(ORCID = "0000-0002-5314-2964")),
    person(given = "Tao",
           family = "Zhao",
           role = "aut",
           email = "tao.zhao@nwafu.edu.cn",
           comment = c(ORCID = "0000-0001-7302-6445")),
    person(given = "Kristian K",
           family = "Ullrich",
           role = "aut",
           email = "ullrich@evolbio.mpg.de",
           comment = c(ORCID = "0000-0003-4308-9626")),
    person(given = "Yves",
           family = "Van de Peer",
           role = "aut",
           email = "yves.vandepeer@psb.vib-ugent.be",
           comment = c(ORCID = "0000-0003-4327-3730"))
    )
Description: syntenet can be used to infer synteny networks from 
    whole-genome protein sequences and analyze them. Anchor pairs
    are detected with the MCScanX algorithm, which was ported to this package
    with the Rcpp framework for R and C++ integration. 
    Anchor pairs from synteny analyses are
    treated as an undirected unweighted graph (i.e., a synteny network),
    and users can perform: i. network clustering; ii. phylogenomic profiling 
    (by identifying which species contain which clusters) and; 
    iii. microsynteny-based phylogeny reconstruction with maximum likelihood.
License: GPL-3
URL: https://github.com/almeidasilvaf/syntenet
BugReports: https://support.bioconductor.org/t/syntenet
biocViews: Software, NetworkInference, FunctionalGenomics,
        ComparativeGenomics, Phylogenetics, SystemsBiology,
        GraphAndNetwork, WholeGenome, Network
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Imports: Rcpp (>= 1.0.8), BiocParallel, GenomicRanges, rlang,
        Biostrings, utils, methods, igraph, stats, grDevices,
        RColorBrewer, pheatmap, ggplot2, ggnetwork, intergraph
Suggests: rtracklayer, BiocStyle, ggtree, labdsv, covr, knitr,
        rmarkdown, testthat (>= 3.0.0), xml2, networkD3
Config/testthat/edition: 3
VignetteBuilder: knitr
LinkingTo: Rcpp, testthat
NeedsCompilation: yes
Depends: R (>= 4.2)
LazyData: false
git_url: https://git.bioconductor.org/packages/syntenet
git_branch: devel
git_last_commit: aa99fce
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
Packaged: 2026-04-29 01:30:34 UTC; biocbuild
Author: Fabrício Almeida-Silva [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5314-2964>),
  Tao Zhao [aut] (ORCID: <https://orcid.org/0000-0001-7302-6445>),
  Kristian K Ullrich [aut] (ORCID:
    <https://orcid.org/0000-0003-4308-9626>),
  Yves Van de Peer [aut] (ORCID: <https://orcid.org/0000-0003-4327-3730>)
Maintainer: Fabrício Almeida-Silva <fabricio_almeidasilva@hotmail.com>
