# Generated by roxygen2: do not edit by hand

export(binarize_and_transpose)
export(check_input)
export(cluster_network)
export(collapse_bidirectional_hits)
export(collapse_protein_ids)
export(create_species_id_table)
export(diamond_is_installed)
export(export_sequences)
export(fasta2AAStringSetlist)
export(find_GS_clusters)
export(gff2GRangesList)
export(infer_microsynteny_phylogeny)
export(infer_syntenet)
export(interspecies_synteny)
export(intraspecies_synteny)
export(iqtree_is_installed)
export(iqtree_version)
export(last_is_installed)
export(make_bidirectional)
export(parse_collinearity)
export(phylogenomic_profile)
export(plot_network)
export(plot_profiles)
export(process_input)
export(profiles2phylip)
export(rcpp_mcscanx_file)
export(read_diamond)
export(run_diamond)
export(run_last)
import(Rcpp)
import(intergraph)
importFrom(BiocParallel,SerialParam)
importFrom(BiocParallel,bplapply)
importFrom(Biostrings,readAAStringSet)
importFrom(Biostrings,subseq)
importFrom(Biostrings,width)
importFrom(Biostrings,writeXStringSet)
importFrom(GenomicRanges,GRangesList)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(GenomicRanges,mcols)
importFrom(RColorBrewer,brewer.pal)
importFrom(ggnetwork,geom_edges)
importFrom(ggnetwork,geom_nodes)
importFrom(ggnetwork,ggnetwork)
importFrom(ggnetwork,theme_blank)
importFrom(ggplot2,aes)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guides)
importFrom(ggplot2,scale_color_manual)
importFrom(grDevices,colorRampPalette)
importFrom(igraph,cluster_infomap)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,simplify)
importFrom(methods,is)
importFrom(pheatmap,pheatmap)
importFrom(rlang,.data)
importFrom(stats,ave)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,reshape)
importFrom(stats,setNames)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,read.table)
importFrom(utils,write.table)
useDynLib(syntenet, .registration = TRUE)
